@@ -9,7 +9,7 @@ class User extends ZM_Object {
 
 	protected $defaults = array(
 			'Id'              => null,
-      'Username'        => '',
+      'Username'        => array('type'=>'text','filter_regexp'=>'/[^\w\.@ ]/'),
       'Password'        => '',
       'Language'        => '',
       'Enabled'         => 1,
@@ -25,7 +25,7 @@ class User extends ZM_Object {
       'MonitorIds'      => '',
       'TokenMinExpiry'  => 0,
       'APIEnabled'      => 1,
-      'HomeView'        =>  '',
+      'HomeView'        => '',
 			);
 
   public static function find( $parameters = array(), $options = array() ) {
